% a_output.m
% This script displays the solution of power flow. The displayed
% information include bus type, voltage, angle, generated real and reactive
% power by the generators, and load power.
%
% Needs:   buType,
%              Vm,
%          Va_deg,
%          calcPg,
%          calcQg,
%    buOriginalPd,
%    buOriginalQd: powr flow solution
% Defines:         NOTHING
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249


% Determine the "human-readable" bus types
for i=1:nBus
    if buType(i) == PV_BUS
        sbuType(i, :) = 'PV';
    elseif buType(i) == PQ_BUS
        sbuType(i, :) = 'PQ';
    else
        sbuType(i, :) = 'Sl';
    end
end
        
% Display the title bar
disp(sprintf('%s', ones(1, 80) * '-'));
disp(sprintf([' Bus  Type   |V| (pu)  /_V (deg)   Pg (MW)     '...
        'Qg (MVAR)   Pd (MW)     Qd (MVAR)']));
disp(sprintf('%s', ones(1, 80) * '-'));

% Display bus data
for i=1:nBus
    disp(sprintf('%3d    %s  \t%5.4f   \t%6.2f  \t%6.2f  \t%6.2f  \t%6.2f  \t%6.2f'...
        , i, sbuType(i, :), Vm(i), Va_deg(i), calcPg(i), calcQg(i), buOriginalPd(i)*1.0,...
        buOriginalQd(i)*1.0));
end

% Display trailing -'s
disp(sprintf('%s', ones(1, 80) * '-'));