% a_pf.m
% This script, Ali's Power Flower, is the main function for solving
% power flow problem. It just calls other modules to do the solution.
% Usage:
%    A_PF([fileName [, resetVoltages]])
% 
% Parameters:
% fileName     : the complete name of data data. Default is set to
%                '12Bus_upfc.dat'
% resetVoltages: a flag. 1 if a flat start is desired, 0 if it is desired
%                to use voltages already in the file as initial values.
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249


%function a_pf(fileName, resetVoltages)
clear all
nargin = 0;

j = sqrt(-1);

% Look for filename
if nargin == 0
    disp(sprintf('\nWARNING: No data file indicated.'))
    disp(sprintf('Usage: a_pf(filename, flatstart)'))
    fileName = '2BusAli.dat';
    fileName = '12BusACraw.raw';
%     fileName = '3bus.dat';
    disp(sprintf('\nTrying to use default file %s...', fileName));
end

% Look for need to reset voltages to 1.0000 and angles to 0
flatStart = true;
flatStart = false;

if nargin == 2
    if resetVoltages
        flatStart = true;
    end
end    

% Initialize some needed variables
a_init

% Read data file and shape data
disp(sprintf('\nReading file %s...', fileName))
a_rawread
disp(sprintf('\nFile read successful.'))

% Create Ybus
disp(sprintf('\nCreating Ybus matrix for %d buses...', nBus));
a_ybus
disp(sprintf('Finished creating Ybus.'));

% Some pre-calculations
a_precalc

% Iterate for the solution
disp(sprintf('\nRunning Newton-Raphson solver...'));
a_newton

% Show the output
disp(sprintf('\nPower flow solution is'));
a_output