% a_precalc.m
% This script resets the bus voltages and angles (in test period). Also,
% sets up the indices of PV and PQ bus types and defines a complex bus
% voltage variable.
%
% Needs:
%       buVoltage: bus voltage magnitudes
%         buAngle: bus voltage angles, in degrees
% Defines:     Vm: bus voltage magnitudes (initially same as buVoltage)
%              Va: bus voltage angles, in radians
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249


% Reset bus voltages and angles to a flat start, if required.
if flatStart
    disp(sprintf(['\nStarting from a flat start, resetting voltage '...
        'magnitudes to 1.0000 and angles to zero...']))
	for i=1:nBus
        if buType(i) == PQ_BUS
            buVoltage(i) = 1.0;
            buAngle(i)   = 0.0;
        elseif buType(i) == PV_BUS
            buAngle(i)   = 0.0;
        end
	end
end

% Form auxiliary vectors for voltage magnitude and angle
buType = buType';

Vm = buVoltage';
Va = buAngle'*pi/180;
V = Vm .* exp(j*Va);