% a_setindices.m
% This script finds and stores indices of PV and PQ buses for easy
% formation of delPQ vector and Jacobian matrix.
%
% Needs:   buType: vector containing bus types
% Defines:     pv,
%              pq: vector of indices of PV and PQ buses, respectively
%              j1,
%              j2,
%              j3,
%              j4,
%              j5,
%              j6: indices of PV and PQ delta and magnitudes. 
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 by Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249


% Find indices of PQ, PV, and Slack buses
pq    = find(buType == PQ_BUS);   % PQ bus indices, load, 1
pv    = find(buType == PV_BUS);   % PV bus indices, gen, 2
slack = find(buType == VD_BUS);   % slack bus index, 3

% Setup the arrangment of PV and PQ buses in Jacobian and mismatch vector
npv = length(pv);
npq = length(pq);
j1 = 1;      j2 = npv;           % j1:j2 - V angle of pv buses
j3 = j2 + 1; j4 = j2 + npq;      % j3:j4 - V angle of pq buses
j5 = j4 + 1; j6 = j4 + npq;      % j5:j6 - V mag of pq buses
