% a_ybus.m
% This script forms Ybus matrix from the data in br___ vectors.
% 
% Needs:    br___: branch data vectors
%            nBus: number of system buses
%         baseMVA: base MVA of the system
% Defines:   Ybus: Ybus matrix
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249



% Calculate series admittance of branchs
brYsr = brStat ./ (brR + j*brX);

% Initialize Ybus
Ybus = zeros(nBus);

% Remove those annoying minus signs
brFrom = abs(brFrom);
brTo = abs(brTo);

% Off-diagonal admittances are the negative of series Y between two buses.
% Observes phase shifts.
for i=1:nBranch
    Ybus(brFrom(i), brTo(i)) = Ybus(brFrom(i), brTo(i)) - brYsr(i)/brRatio(i);
    Ybus(brTo(i), brFrom(i)) = Ybus(brTo(i), brFrom(i)) - brYsr(i)/conj(brRatio(i));
end

% On-diagonal admittances are sum of admittances between the bus and other
% buses including ground.
for i=1:nBus
    for k=1:nBranch
        if brFrom(k)==i
            Ybus(i, i) = Ybus(i, i) + brYsr(k)/(brRatio(k)*conj(brRatio(k))) + j*brB(k)/2;
        elseif brTo(k)==i
            Ybus(i, i) = Ybus(i, i) + brYsr(k) + j*brB(k)/2;
        end
    end
end

% Add switched shunt data as constant impedance capacitors.
for i=1:nSwitched
    Ybus(swBus(i), swBus(i)) = Ybus(swBus(i), swBus(i)) + j*swBInit(i)/baseMVA;     
end