% at_DefineLoadTypes.m
% This script is used to define load types. Portions of each load can be
% modeled as constant impedance, constant current, constant power, or
% exponential recovery model at the same time. Each portion is defined by
% its respective constant. Also for exponential recovery model, the
% exponents and time constant are defined here. Assumes loads can be
% connected to all buses.
%
% Needs: 
%            nLoad: Number of load buses
%             nGen: Number of generator buses
%
% Defines:   
% K_pz, K_pi, K_pp,
%             K_pe: Portions of active power modeled as ZIP and ER
% K_qz, K_qi, K_qq,
%             K_qe: Portions of reactive power modeled as ZIP and ER
%   n_ptER, n_qtER: Exponents used in P_t(V) and Q_t(V), respectively
%   n_psER, n_qsER: Exponents used in P_s(V) and Q_s(V), respectively
%     T_pER, T_qER: Time constants of ER model
%
% Part of the code written for GPFM strategy,
% submitted to IEEE Transactions on Smart Grid, July 2011.
%
% Copyright (c) 2012 by Ali Mehrizi-Sani
% Washington State University
% mehrizi@eecs.wsu.edu
% http://eecs.wsu.edu/~mehrizi
% (509) 335-6249


% Define active power portions modeled as each type
K_pz = [ones(nLoad, 1)*0.90; zeros(nGen, 1)];
K_pi = [ones(nLoad, 1)*0.05; zeros(nGen, 1)];
K_pp = [ones(nLoad, 1)*0.04; zeros(nGen, 1)];
K_pe = [ones(nLoad, 1)*0.01; zeros(nGen, 1)];

% Define reactive power portions modeled as each type
K_qz = [ones(nLoad, 1)*0.80; zeros(nGen, 1)];
K_qi = [ones(nLoad, 1)*0.00; zeros(nGen, 1)];
K_qq = [ones(nLoad, 1)*0.00; zeros(nGen, 1)];
K_qe = [ones(nLoad, 1)*0.20; zeros(nGen, 1)];

% Define active power parameters of exponential recovery model
n_ptER = [ones(nLoad, 1)*2.00; zeros(nGen, 1)];
n_psER = [ones(nLoad, 1)*2.00; zeros(nGen, 1)];
T_pER  = [ones(nLoad, 1)*0.05; ones(nGen, 1)];

% Define reactive power parameters of exponential recovery model
n_qtER = [ones(nLoad, 1)*2.00; zeros(nGen, 1)];
n_qsER = [ones(nLoad, 1)*2.00; zeros(nGen, 1)];
T_qER  = [ones(nLoad, 1)*0.05; ones(nGen, 1)];